@@ -184,7 +184,7 @@ client_prepare_incr(struct client *c, enum arith_cmd_e cmd, int key_index,
 extern
 int
 client_prepare_delete(struct client *c, int key_index,
-                      const char *key, size_t key_len, delay_type delay);
+                      const char *key, size_t key_len);
 
 extern
 int
